@@ -1,23 +1,8 @@
 /*
- * Copyright (C) 2008,2009,2010,2012,2016,2017
- *               Rolf Eike Beer <kde@opensource.sf-tec.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "KGpgGroupNode.h"
 
 #include "kgpg_general_debug.h"
@@ -30,7 +15,6 @@
 
 #include <QFile>
 #include <QRegularExpression>
-#include <QStringList>
 #include <QTextStream>
 
 class KGpgGroupNodePrivate {
@@ -84,7 +68,11 @@ KGpgGroupNodePrivate::findGroupEntry(QFile &conffile, QTextStream &stream, QStri
 			// remove "group "
 			parsedLine.remove(0, 6);
 			if (parsedLine.startsWith(m_name)) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 				if (parsedLine.midRef(m_name.length()).trimmed().startsWith(QLatin1Char('='))) {
+#else
+				if (QStringView(parsedLine).mid(m_name.length()).trimmed().startsWith(QLatin1Char('='))) {
+#endif
 					if (index >= 0) {
 						// multiple definitions of the same group, drop the second one
 						continue;
