@@ -50,10 +50,16 @@
 #include "transactions/kgpgtransactionjob.h"
 
 #include <algorithm>
-
+#include <akonadi-contact_version.h>
+#if AKONADICONTACT_VERSION > QT_VERSION_CHECK(5, 19, 40)
+#include <Akonadi/ContactEditor>
+#include <Akonadi/ContactEditorDialog>
+#include <Akonadi/ContactSearchJob>
+#else
 #include <Akonadi/Contact/ContactEditor>
 #include <Akonadi/Contact/ContactEditorDialog>
 #include <Akonadi/Contact/ContactSearchJob>
+#endif
 #include <KActionCollection>
 #include <KContacts/AddresseeList>
 // #include <KContacts/Key> TODO
@@ -61,7 +67,12 @@
 #include <KIO/Global>
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/OpenUrlJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -743,7 +754,7 @@ void KeysManager::refreshKeyFromServer()
 		if (item->getType() & ITYPE_PAIR) {
 			keyIDS << item->getId();
 		} else {
-			KMessageBox::sorry(this, i18n("You can only refresh primary keys. Please check your selection."));
+			KMessageBox::error(this, i18n("You can only refresh primary keys. Please check your selection."));
 			return;
 		}
 	}
@@ -1039,7 +1050,7 @@ void KeysManager::slotAddressbookSearchResult(KJob *job)
 
 void KeysManager::slotManpage()
 {
-	const KService::Ptr helpCenter = KService::serviceByDesktopName(QStringLiteral("org.kde.help"));
+	const KService::Ptr helpCenter = KService::serviceByDesktopName(QStringLiteral("org.kde.khelpcenter"));
 	auto job = new KIO::ApplicationLauncherJob(helpCenter);
 	job->setUrls({QUrl(QStringLiteral("man:/gpg"))});
 	job->start();
@@ -1354,7 +1365,7 @@ void KeysManager::slotRevokeGenerated(int result)
 	case KGpgTransaction::TS_USER_ABORTED:
 		break;
 	default:
-		KMessageBox::detailedSorry(this, i18n("Creation of the revocation certificate failed..."), genRev->getOutput());
+		KMessageBox::detailedError(this, i18n("Creation of the revocation certificate failed..."), genRev->getOutput());
 		break;
 	}
 }
@@ -1402,7 +1413,7 @@ void KeysManager::slotExportSecFinished(int result)
 				i18n("<qt>Your <b>private</b> key \"%1\" was successfully exported to<br/>%2.<br/><b>Do not</b> leave it in an insecure place.</qt>",
 				exp->getKeyIds().first(), exp->getOutputFile()));
 	} else {
-		KMessageBox::sorry(this, i18n("Your secret key could not be exported.\nCheck the key."));
+		KMessageBox::error(this, i18n("Your secret key could not be exported.\nCheck the key."));
 	}
 }
 
@@ -1508,7 +1519,7 @@ void KeysManager::slotExportFinished(int result)
 						"<qt>The %1 public keys were successfully exported to<br/>%2</qt>",
 						exp->getKeyIds().count(), exp->getOutputFile()));
 	} else {
-		KMessageBox::sorry(this, i18n("Your public key could not be exported\nCheck the key."));
+		KMessageBox::error(this, i18n("Your public key could not be exported\nCheck the key."));
 	}
 
 	exp->deleteLater();
@@ -1523,7 +1534,7 @@ void KeysManager::slotProcessExportMail(int result)
 	if (result == KGpgTransaction::TS_OK) {
 		QDesktopServices::openUrl(QUrl(QLatin1String("mailto:?body=") + QLatin1String(exp->getOutputData())));
 	} else {
-		KMessageBox::sorry(this, i18n("Your public key could not be exported\nCheck the key."));
+		KMessageBox::error(this, i18n("Your public key could not be exported\nCheck the key."));
 	}
 
 	exp->deleteLater();
@@ -1537,7 +1548,7 @@ void KeysManager::slotProcessExportClip(int result)
 	if (result == KGpgTransaction::TS_OK) {
 		qApp->clipboard()->setText(QLatin1String( exp->getOutputData() ), m_clipboardmode);
 	} else {
-		KMessageBox::sorry(this, i18n("Your public key could not be exported\nCheck the key."));
+		KMessageBox::error(this, i18n("Your public key could not be exported\nCheck the key."));
 	}
 
 	exp->deleteLater();
@@ -1709,7 +1720,7 @@ void KeysManager::createNewGroup()
 	if (ndlist.empty())
 		return;
 	if (tp & ~ITYPE_PAIR) {
-		KMessageBox::sorry(this, i18n("<qt>You cannot create a group containing signatures, subkeys or other groups.</qt>"));
+		KMessageBox::error(this, i18n("<qt>You cannot create a group containing signatures, subkeys or other groups.</qt>"));
 		return;
 	}
 
@@ -1740,7 +1751,7 @@ void KeysManager::createNewGroup()
 		iview->selectNode(imodel->addGroup(groupName, keysList));
 		updateStatusCounter();
         } else {
-		KMessageBox::sorry(this,
+		KMessageBox::error(this,
 				i18n("<qt>No valid or trusted key was selected. The group <b>%1</b> will not be created.</qt>",
 				groupName));
 	}
@@ -1789,7 +1800,7 @@ void KeysManager::signkey()
 		return;
 
 	if (tp & ~ITYPE_PAIR) {
-		KMessageBox::sorry(this, i18n("You can only sign primary keys. Please check your selection."));
+		KMessageBox::error(this, i18n("You can only sign primary keys. Please check your selection."));
 		return;
 	}
 
@@ -1868,7 +1879,7 @@ void KeysManager::signuid()
 		return;
 
 	if (tp & ~(ITYPE_PAIR | ITYPE_UID | ITYPE_UAT)) {
-		KMessageBox::sorry(this, i18n("You can only sign user ids and photo ids. Please check your selection."));
+		KMessageBox::error(this, i18n("You can only sign user ids and photo ids. Please check your selection."));
 		return;
 	}
 
@@ -1981,11 +1992,11 @@ void KeysManager::signatureResult(int success)
 			refreshList.append(nd);
 		break;
 	case KGpgTransaction::TS_BAD_PASSPHRASE:
-		KMessageBox::sorry(this, i18n("<qt>Bad passphrase, key <b>%1 (%2)</b> not signed.</qt>",
+		KMessageBox::error(this, i18n("<qt>Bad passphrase, key <b>%1 (%2)</b> not signed.</qt>",
 				nd->getName(), nd->getEmail()));
 		break;
 	case KGpgSignTransactionHelper::TS_ALREADY_SIGNED:
-		KMessageBox::sorry(this, i18n("<qt>The key <b>%1 (%2)</b> is already signed.</qt>",
+		KMessageBox::error(this, i18n("<qt>The key <b>%1 (%2)</b> is already signed.</qt>",
 				nd->getName(), nd->getEmail()));
 		break;
 	default:
@@ -2015,7 +2026,7 @@ void KeysManager::caff()
 		return;
 
 	if (tp & ~(ITYPE_PAIR | ITYPE_UID | ITYPE_UAT)) {
-		KMessageBox::sorry(this, i18n("You can only sign user ids and photo ids. Please check your selection."));
+		KMessageBox::error(this, i18n("You can only sign user ids and photo ids. Please check your selection."));
 		return;
 	}
 
@@ -2198,7 +2209,7 @@ void KeysManager::delsignkey()
 		signMail += QLatin1String( " &lt;" ) + nd->getEmail() + QLatin1String( "&gt;" );
 
 	if (parentKey == signID) {
-		KMessageBox::sorry(this, i18n("Edit key manually to delete a self-signature."));
+		KMessageBox::error(this, i18n("Edit key manually to delete a self-signature."));
 		return;
 	}
 
@@ -2224,7 +2235,7 @@ void KeysManager::delsignatureResult(int success)
 			nd = nd->getParentKeyNode();
 		imodel->refreshKey(nd->toKeyNode());
 	} else {
-		KMessageBox::sorry(this, i18n("Requested operation was unsuccessful, please edit the key manually."));
+		KMessageBox::error(this, i18n("Requested operation was unsuccessful, please edit the key manually."));
 	}
 }
 
@@ -2416,21 +2427,14 @@ void KeysManager::confirmdeletekey()
 		slotDelUid();
 		return;
 	} else if ((pt & ITYPE_GROUP) && !(pt & ~ITYPE_GPAIR)) {
-		bool invalidDelete = false;
-		for (const KGpgNode *nd : ndlist)
-			if (nd->getType() == ITYPE_GROUP) {
-				invalidDelete = true;
-				break;
-			}
+		bool invalidDelete = std::any_of(ndlist.cbegin(), ndlist.cend(),
+				[](const KGpgNode *nd) { return nd->getType() == ITYPE_GROUP; });
 
 		// only allow removing group members if they belong to the same group
 		if (!invalidDelete) {
 			const KGpgNode * const group = ndlist.front()->getParentKeyNode();
-			for (const KGpgNode *nd : ndlist)
-				if (nd->getParentKeyNode() != group) {
-					invalidDelete = true;
-					break;
-				}
+			invalidDelete = std::any_of(ndlist.cbegin(), ndlist.cend(),
+					[group] (const KGpgNode *nd) { return nd->getParentKeyNode() != group; });
 		}
 
 		if (!invalidDelete) {
@@ -2592,7 +2596,7 @@ void KeysManager::slotImportDone(int result)
 	const QStringList rawmsgs(import->getMessages());
 
 	if (result != 0) {
-		KMessageBox::detailedSorry(this, i18n("Key importing failed. Please see the detailed log for more information."),
+		KMessageBox::detailedError(this, i18n("Key importing failed. Please see the detailed log for more information."),
 				rawmsgs.join(QLatin1String("\n")) , i18n("Key Import"));
 	}
 
@@ -2800,7 +2804,11 @@ KeysManager::slotOpenKeyUrl()
 	url.replace(QLatin1String("$$fpr$$"), idLC);
 
 	auto *job = new KIO::OpenUrlJob(QUrl(url));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+	job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
 	job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
 	job->start();
 }
 
