@@ -1,19 +1,7 @@
-/***************************************************************************
-                          kgpg.h  -  description
-                             -------------------
-    begin                : Mon Nov 18 2002
-    copyright          : (C) 2002 by Jean-Baptiste Mardelle
-    email                : bj@altern.org
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KGPGAPPLET_H
 #define KGPGAPPLET_H
@@ -46,7 +34,7 @@ class KGpgApp : public QApplication
 
 public:
     KGpgApp(int &argc, char **argv);
-    ~KGpgApp();
+    ~KGpgApp() override;
 
 	bool newInstance();
 	QKeySequence goHome;
