@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2008,2009,2010,2012,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgchangekey.h"
 
@@ -58,7 +50,7 @@ void KGpgChangeKey::setOwTrust(const gpgme_validity_t trust)
 bool KGpgChangeKey::apply()
 {
 	if (!wasChanged()) {
-		emit done(0);
+		Q_EMIT done(0);
 		return true;
 	}
 
@@ -144,10 +136,10 @@ void KGpgChangeKey::nextStep(int result)
 			m_failed |= 4;
 		}
 		m_step = 0;
-		emit done(m_failed);
+		Q_EMIT done(m_failed);
 		if (m_autodestroy) {
 			if (m_node)
-				emit keyNeedsRefresh(m_node);
+				Q_EMIT keyNeedsRefresh(m_node);
 			deleteLater();
 		}
 	}
