@@ -9,11 +9,9 @@
 #include <QObject>
 
 #include <QUrl>
-
+#include <QStringList>
 #include "kgpgtextorfiletransaction.h"
 
-class QStringList;
-
 /**
  * @brief decrypt the given text or files
  */
