@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2010, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgdelsign.h"
 
@@ -120,13 +112,13 @@ KGpgDelSign::boolQuestion(const QString &line)
 		if (signode == nullptr)
 			return KGpgTransaction::BA_NO;
 
-		const QDateTime creation = QDateTime::fromTime_t(parts[5].toUInt());
+		const QDateTime creation = QDateTime::fromSecsSinceEpoch(parts[5].toUInt());
 		if (creation != signode->getCreation())
 			return KGpgTransaction::BA_NO;
 
 		QDateTime sigexp;
 		if (!parts[6].isEmpty() && (parts[6] != QLatin1String("0")))
-			sigexp = QDateTime::fromTime_t(parts[6].toUInt());
+			sigexp = QDateTime::fromSecsSinceEpoch(parts[6].toUInt());
 		if (sigexp != signode->getExpiration())
 			return KGpgTransaction::BA_NO;
 
