@@ -1,15 +1,7 @@
 /*
- * Copyright (C) 2008,2009,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008, 2009, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgdeluid.h"
 
@@ -122,7 +114,7 @@ KGpgDelUid::setUid(const KGpgKeyNode *keynode, const int uid, const RemoveMode r
 		Q_ASSERT(keynode->wasExpanded());
 		int idx = 0;
 
-		forever {
+        while(1) {
 			idx++;
 			if (idx == -uid)
 				continue;
